Unknown hint issues

Hint issues without minimal reproducers yet:

- Links should be correctly positioned on metafilter.com - see #824 (comment).
  Current state: good
- Links should be correctly positioned on xkcd.org - see #824.
  Current state: good - fixed in #1433
- links should be correctly positioned on this exherbo.org page - see #1003.
  current state: bad
- links should be correctly positioned on this ctl.io page - see #824 (comment).
  Current state: good - fixed in #1433
- When clicking titles under the images on etsy, the correct item should be selected (sometimes the one on the right is selected instead) - see #1005.
  Current state: good - fixed in #1433
- When clicking titles on Geizhals, the correct item should be selected (one of the sub-titles is selected instead) - see #1514.
  Current state: good - fixed in #1433